@@ -19,15 +19,15 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#ifdef HAVE_SYSLOG_H
-#  include <syslog.h>
-#endif /* HAVE_SYSLOG_H */
 #include <errno.h>
 #include "errors.h"
+#include "config.h"
 
 
-/* compatability section */
-#ifndef HAVE_SYSLOG_H
+/* compatibility section */
+#ifdef HAVE_SYSLOG_H
+#  include <syslog.h>
+#else /* HAVE_SYSLOG_H */
 #warning no syslog facility?  Errors will go to stderr.
 #  define syslog(x,y,z)
 #  define LOG_DEBUG	7
@@ -42,7 +42,7 @@
 #ifndef HAVE_STRERROR
 #define strerror(x) "system error"
 #endif
-/* end compatability section */
+/* end compatibility section */
 
 static char *progname = NULL;
 
@@ -66,7 +66,7 @@ int status(const char *fmt, ...) {
 
     if(!show_status) return(0);
     va_start(args, fmt);
-    vsprintf(buf, fmt, args);
+    vsnprintf(buf, sizeof(buf), fmt, args);
     va_end(args);
     return(message(LOG_DEBUG, buf));
 }
@@ -76,7 +76,7 @@ int warn(const char *fmt, ...) {
     va_list args;
 
     va_start(args, fmt);
-    vsprintf(buf, fmt, args);
+    vsnprintf(buf, sizeof(buf), fmt, args);
     va_end(args);
     return(message(LOG_WARNING, buf));
 }
@@ -86,7 +86,7 @@ int panic(const char *fmt, ...) {
     va_list args;
 
     va_start(args, fmt);
-    vsprintf(buf, fmt, args);
+    vsnprintf(buf, sizeof(buf), fmt, args);
     va_end(args);
     message(LOG_ERR, buf);
     exit(1);
@@ -97,7 +97,7 @@ int message(int priority, const char *msg) {
 
     /* only handle errno if this is not an informational message */
     if(errno && priority < 5) {
-	sprintf(buf, "%s: %s", msg, strerror(errno));
+	snprintf(buf, sizeof(buf), "%s: %s", msg, strerror(errno));
 	errno = 0;
     } else strcpy(buf, msg);
     if(use_syslog) syslog(priority, "%s", buf);
